@@ -1,7 +1,9 @@
 # Copyright (c) 2018 Ultimaker B.V.
 # Uranium is released under the terms of the LGPLv3 or higher.
+from UM.Scene.Iterator.DepthFirstIterator import DepthFirstIterator
 from UM.Scene.Scene import Scene
 from UM.Event import Event, KeyEvent, MouseEvent, ToolEvent, ViewEvent
+from UM.Scene.SceneNode import SceneNode
 from UM.Signal import Signal, signalemitter
 from UM.Logger import Logger
 from UM.PluginRegistry import PluginRegistry
@@ -12,7 +14,6 @@ from UM.Stage import Stage
 from UM.InputDevice import InputDevice
 from typing import cast, Optional, Dict, Union
 from UM.Math.Vector import Vector
-
 MYPY = False
 if MYPY:
     from UM.Application import Application
@@ -271,6 +272,8 @@ class Controller:
                 Logger.log("w", "Controller does not have an active tool and could not default to Translate tool.")
 
         if tool_changed:
+            Selection.setFaceSelectMode(False)
+            Selection.clearFace()
             self.activeToolChanged.emit()
 
     ##  Emitted when the list of tools changes.
@@ -369,6 +372,37 @@ class Controller:
     def setToolsEnabled(self, enabled: bool) -> None:
         self._tools_enabled = enabled
 
+    def deleteAllNodesWithMeshData(self, only_selectable:bool = True) -> None:
+        Logger.log("i", "Clearing scene")
+        if not self.getToolsEnabled():
+            return
+
+        nodes = []
+        for node in DepthFirstIterator(self.getScene().getRoot()):
+            if not node.isEnabled():
+                continue
+            if not node.getMeshData() and not node.callDecoration("isGroup"):
+                continue  # Node that doesnt have a mesh and is not a group.
+            if only_selectable and not node.isSelectable():
+                continue  # Only remove nodes that are selectable.
+            if node.getParent() and cast(SceneNode, node.getParent()).callDecoration("isGroup"):
+                continue  # Grouped nodes don't need resetting as their parent (the group) is resetted)
+            nodes.append(node)
+        if nodes:
+            from UM.Operations.GroupedOperation import GroupedOperation
+            op = GroupedOperation()
+
+            for node in nodes:
+                from UM.Operations.RemoveSceneNodeOperation import RemoveSceneNodeOperation
+                op.addOperation(RemoveSceneNodeOperation(node))
+
+                # Reset the print information
+                self.getScene().sceneChanged.emit(node)
+
+            op.push()
+            from UM.Scene.Selection import Selection
+            Selection.clear()
+
     # Rotate camera view according defined angle
     def setCameraRotation(self, coordinate: str = "x", angle: int = 0) -> None:
         camera = self._scene.getActiveCamera()
@@ -401,7 +435,7 @@ class Controller:
                     # Actually set the top view.
                     camera.setPosition(Vector(0, 800, 1))
                     camera.lookAt(Vector(0, 100, 1))
-                    # Note the absence of rotation at the end!
+                    self._camera_tool.rotateCamera(0, 0)  # type: ignore
                 else:
                     camera.setPosition(Vector(0, 100, 700))
                     camera.lookAt(Vector(0, 100, 0))
