@@ -56,7 +56,6 @@ class LocalContainerProvider(ContainerProvider):
 
         container = None  # type: Optional[ContainerInterface]
 
-        Logger.log("d", "Loading container {container_id}".format(container_id = base_id))
         container_class = ContainerRegistry.mime_type_map[self._id_to_mime[base_id].name]
         if issubclass(container_class, DefinitionContainer):  # We may need to load these from the definition cache.
             container = self._loadCachedDefinition(container_id)
@@ -129,7 +128,7 @@ class LocalContainerProvider(ContainerProvider):
         if container_id in registry.metadata:
             return registry.metadata[container_id]
 
-        filename = self._id_to_path[container_id] #Raises KeyError if container ID does not exist in the (cache of the) files!
+        filename = self._id_to_path[container_id]  # Raises KeyError if container ID does not exist in the (cache of the) files!
         clazz = ContainerRegistry.mime_type_map[self._id_to_mime[container_id].name]
 
         requested_metadata = {}  # type: Dict[str, Any]
@@ -151,10 +150,10 @@ class LocalContainerProvider(ContainerProvider):
                 continue
             if metadata["id"] == container_id:
                 requested_metadata = metadata
-            #Side-load the metadata into the registry if we get multiple containers.
-            if metadata["id"] not in registry.metadata: #This wouldn't get loaded normally.
+            # Side-load the metadata into the registry if we get multiple containers.
+            if metadata["id"] not in registry.metadata:  # This wouldn't get loaded normally.
                 self._id_to_path[metadata["id"]] = filename
-                self._id_to_mime[metadata["id"]] = self._id_to_mime[container_id] #Assume that they only return one MIME type.
+                self._id_to_mime[metadata["id"]] = self._id_to_mime[container_id]  # Assume that they only return one MIME type.
                 registry.metadata[metadata["id"]] = metadata
                 registry.source_provider[metadata["id"]] = self
         return requested_metadata
@@ -217,9 +216,9 @@ class LocalContainerProvider(ContainerProvider):
             cache_path = Resources.getPath(Resources.Cache, "definitions", Application.getInstance().getVersion(), definition_id)
             cache_mtime = os.path.getmtime(cache_path)
             definition_mtime = os.path.getmtime(definition_path)
-        except FileNotFoundError: #Cache doesn't exist yet.
+        except FileNotFoundError:  # Cache doesn't exist yet.
             return None
-        except PermissionError: #No read permission.
+        except PermissionError:  # No read permission.
             return None
 
         if definition_mtime > cache_mtime:
@@ -239,7 +238,7 @@ class LocalContainerProvider(ContainerProvider):
                 if os.path.getmtime(file_path) > cache_mtime:
                     return None
         except FileNotFoundError:
-            return None #Cache for parent doesn't exist yet.
+            return None  # Cache for parent doesn't exist yet.
 
         return definition
 
@@ -299,7 +298,8 @@ class LocalContainerProvider(ContainerProvider):
     ##  Converts a file path to the MIME type of the container it represents.
     #
     #   \return The MIME type or None if it's not a container.
-    def _pathToMime(self, path: str) -> Optional[MimeType]:
+    @staticmethod
+    def _pathToMime(path: str) -> Optional[MimeType]:
         try:
             mime = MimeTypeDatabase.getMimeTypeForFile(path)
         except MimeTypeDatabase.MimeTypeNotFoundError:
@@ -310,9 +310,10 @@ class LocalContainerProvider(ContainerProvider):
         return mime
 
     ##  Converts a file path to the ID of the container it represents.
-    def _pathToId(self, path: str) -> Optional[str]:
+    @staticmethod
+    def _pathToId(path: str) -> Optional[str]:
         result = None
-        mime = self._pathToMime(path)
+        mime = LocalContainerProvider._pathToMime(path)
         if mime:
             result = urllib.parse.unquote_plus(mime.stripExtension(os.path.basename(path)))
         return result
